<?php

if (!defined('BASEPATH'))
    exit('No direct script access allowed');

/**
 * Email callback
 *
 * @author Igor Ratsun
 */
class Rtgc_email extends \Rtgc_input
{
    protected $options = [
        'type'        => 'email',
        'class'       => 'input-xxlarge',
        'placeholder' => 'email@email.com',
    ];

    public function column($value = '', $data = array())
    {
        return '<a href="mailto:' . $value . '">' . $value . '</a>';
    }

}
